@@ -1,39 +1,61 @@
 """Async executor versions of file functions from the os module."""
-import asyncio
-from functools import partial, wraps
+
 import os
 
-
-def wrap(func):
-    @wraps(func)
-    async def run(*args, loop=None, executor=None, **kwargs):
-        if loop is None:
-            loop = asyncio.get_running_loop()
-        pfunc = partial(func, *args, **kwargs)
-        return await loop.run_in_executor(executor, pfunc)
-
-    return run
-
-
 from . import ospath as path
+from .base import wrap
 
+__all__ = [
+    "path",
+    "stat",
+    "rename",
+    "renames",
+    "replace",
+    "remove",
+    "unlink",
+    "mkdir",
+    "makedirs",
+    "rmdir",
+    "removedirs",
+    "symlink",
+    "readlink",
+    "listdir",
+    "scandir",
+    "access",
+    "wrap",
+    "getcwd",
+]
 
-stat = wrap(os.stat)
+access = wrap(os.access)
+
+getcwd = wrap(os.getcwd)
+
+listdir = wrap(os.listdir)
+
+makedirs = wrap(os.makedirs)
+mkdir = wrap(os.mkdir)
+
+readlink = wrap(os.readlink)
+remove = wrap(os.remove)
+removedirs = wrap(os.removedirs)
 rename = wrap(os.rename)
 renames = wrap(os.renames)
 replace = wrap(os.replace)
-remove = wrap(os.remove)
-unlink = wrap(os.unlink)
-mkdir = wrap(os.mkdir)
-makedirs = wrap(os.makedirs)
 rmdir = wrap(os.rmdir)
-removedirs = wrap(os.removedirs)
-link = wrap(os.link)
-symlink = wrap(os.symlink)
-readlink = wrap(os.readlink)
-listdir = wrap(os.listdir)
-scandir = wrap(os.scandir)
-access = wrap(os.access)
 
+scandir = wrap(os.scandir)
+stat = wrap(os.stat)
+symlink = wrap(os.symlink)
+
+unlink = wrap(os.unlink)
+
+
+if hasattr(os, "link"):
+    __all__ += ["link"]
+    link = wrap(os.link)
 if hasattr(os, "sendfile"):
+    __all__ += ["sendfile"]
     sendfile = wrap(os.sendfile)
+if hasattr(os, "statvfs"):
+    __all__ += ["statvfs"]
+    statvfs = wrap(os.statvfs)
